@@ -51,12 +51,16 @@
 #include "panel-position.h"
 #include "panel-save-delegate.h"
 #include "panel-widget-private.h"
-#include "panel-macros.h"
 
+/**
+ * PanelWidget:
+ *
+ * PanelWidget is the base widget class for widgets added to a
+ * #PanelFrame. It can be use as-is or you can subclass it.
+ */
 typedef struct
 {
   GtkWidget         *child;
-  GQuark             kind;
   char              *title;
   char              *icon_name;
   GIcon             *icon;
@@ -69,15 +73,17 @@ typedef struct
   GtkWidget         *maximize_frame;
   GtkWidget         *maximize_dock_child;
 
-  guint             busy_count;
+  GQuark             kind;
 
-  guint             reorderable : 1;
-  guint             can_maximize : 1;
-  guint             maximized : 1;
-  guint             modified : 1;
-  guint             needs_attention : 1;
-  guint             saving : 1;
-  guint             force_close : 1;
+  guint              busy_count;
+
+  guint              reorderable : 1;
+  guint              can_maximize : 1;
+  guint              maximized : 1;
+  guint              modified : 1;
+  guint              needs_attention : 1;
+  guint              saving : 1;
+  guint              force_close : 1;
 } PanelWidgetPrivate;
 
 typedef struct
@@ -258,7 +264,7 @@ panel_widget_save_action (GtkWidget  *widget,
  *
  * Create a new #PanelWidget.
  *
- * Returns: (transfer full): a newly created #PanelWidget
+ * Returns: a newly created #PanelWidget
  */
 GtkWidget *
 panel_widget_new (void)
@@ -342,10 +348,12 @@ panel_widget_dispose (GObject *object)
       g_clear_object (&priv->action_muxer);
     }
 
-  g_clear_pointer (&priv->icon_name, g_free);
-  g_clear_pointer (&priv->title, g_free);
   g_clear_pointer (&priv->child, gtk_widget_unparent);
+  g_clear_pointer (&priv->title, g_free);
+  g_clear_pointer (&priv->icon_name, g_free);
   g_clear_object (&priv->icon);
+  g_clear_pointer (&priv->id, g_free);
+  g_clear_pointer (&priv->tooltip, g_free);
   g_clear_object (&priv->menu_model);
   g_clear_object (&priv->save_delegate);
 
@@ -746,7 +754,7 @@ panel_widget_set_icon_name (PanelWidget *self,
 
   g_return_if_fail (PANEL_IS_WIDGET (self));
 
-  if (panel_set_string (&priv->icon_name, icon_name))
+  if (g_set_str (&priv->icon_name, icon_name))
     {
       g_clear_object (&priv->icon);
       g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_ICON_NAME]);
@@ -803,6 +811,14 @@ panel_widget_set_icon (PanelWidget *self,
     }
 }
 
+/**
+ * panel_widget_get_id:
+ * @self: a #PanelWidget
+ *
+ * Gets the id of the panel widget.
+ *
+ * Returns: (transfer none): The id of the panel widget.
+ */
 const char *
 panel_widget_get_id (PanelWidget *self)
 {
@@ -813,6 +829,13 @@ panel_widget_get_id (PanelWidget *self)
   return priv->id;
 }
 
+/**
+ * panel_widget_set_id:
+ * @self: a #PanelWidget
+ * @id: (transfer none): the id to set for the panel widget.
+ *
+ * Sets the id of the panel widget.
+ */
 void
 panel_widget_set_id (PanelWidget *self,
                      const char  *id)
@@ -821,10 +844,18 @@ panel_widget_set_id (PanelWidget *self,
 
   g_return_if_fail (PANEL_IS_WIDGET (self));
 
-  if (panel_set_string (&priv->id, id))
+  if (g_set_str (&priv->id, id))
     g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_ID]);
 }
 
+/**
+ * panel_widget_get_modified:
+ * @self: a #PanelWidget
+ *
+ * Gets the modified status of a panel widget
+ *
+ * Returns: the modified status of the panel widget.
+ */
 gboolean
 panel_widget_get_modified (PanelWidget *self)
 {
@@ -835,6 +866,13 @@ panel_widget_get_modified (PanelWidget *self)
   return priv->modified;
 }
 
+/**
+ * panel_widget_set_modified:
+ * @self: a #PanelWidget
+ * @modified: the modified status
+ *
+ * Sets the modified status of a panel widget.
+ */
 void
 panel_widget_set_modified (PanelWidget *self,
                            gboolean     modified)
@@ -886,7 +924,7 @@ panel_widget_set_title (PanelWidget *self,
 
   g_return_if_fail (PANEL_IS_WIDGET (self));
 
-  if (panel_set_string (&priv->title, title))
+  if (g_set_str (&priv->title, title))
     g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_TITLE]);
 }
 
@@ -923,7 +961,7 @@ panel_widget_set_tooltip (PanelWidget *self,
 
   g_return_if_fail (PANEL_IS_WIDGET (self));
 
-  if (panel_set_string (&priv->tooltip, tooltip))
+  if (g_set_str (&priv->tooltip, tooltip))
     g_object_notify_by_pspec (G_OBJECT (self), properties [PROP_TOOLTIP]);
 }
 
